Name: valgrind
Version: 2.4.0
#define cvsdate 20040522
Release: alt1

Summary: Valgrind, an open-source memory debugger for x86-GNU/Linux
License: GPL
Group: Development/Other
URL: http://www.valgrind.org/

%ifdef cvsdate
Source: %name-%cvsdate.tar.bz2
%else
Source: http://www.valgrind.org/downloads/%name-%version.tar.bz2
%endif

Patch1: %name-2.4.0-alt-funobj-suppression.patch
Patch2: %name-2.4.0-alt-suppressions.patch
Patch3: %name-2.4.0-alt-intercept-strmem.patch
Patch4: %name-2.4.0-alt-ume-ET_DYN-fixup.patch

# Automatically added by buildreq on Wed May 05 2004
BuildRequires: XFree86-devel XFree86-libs gcc-c++ gdb glibc-devel-static

%description
Valgrind is a GPL'd tool to help you find memory-management problems
in your programs.  When a program is run under Valgrind's supervision,
all reads and writes of memory are checked, and calls to
malloc/new/free/delete are intercepted.  As a result, Valgrind can
detect problems such as:

    * Use of uninitialised memory
    * Reading/writing memory after it has been free'd
    * Reading/writing off the end of malloc'd blocks
    * Reading/writing inappropriate areas on the stack
    * Memory leaks -- where pointers to malloc'd blocks are lost forever
    * Passing of uninitialised and/or unaddressible memory to system calls
    * Mismatched use of malloc/new/new [] vs free/delete/delete []
    * Overlaps of arguments to strcpy() and related functions
    * Some abuses of the POSIX pthread API

%package devel
Summary: Valgrind header files for embedding Valgrind checks into other applications
Group: Development/Other
Requires: %name = %version-%release

%description devel
Valgrind-devel contains header files for providing macros to embed
Valgrind checks into other applications.  The resulting executables
will still run without Valgrind, just a little bit more slowly than
they otherwise would, but otherwise unchanged.

When run on Valgrind with --client-perms=yes, Valgrind observes these
macro calls and takes appropriate action.  When run on Valgrind with
--client-perms=no (the default), Valgrind observes these macro calls
but does not take any action as a result.

%prep
%setup -q %{?cvsdate:-n %name}
%patch1 -p1 -b .alt-funobj-suppression
%patch2 -p1 -b .alt-suppressions

%__mv memcheck/mac_replace_strmem.c memcheck/mac_replace_strmem.c.base
%patch3 -p1 -b .alt-intercept-strmem

%patch4 -p1 -b .alt-ume-ET_DYN-fixup

%build
#%{?cvsdate:./autogen.sh}
autoreconf -vi
%configure
%make_build

%install
%make_install install DESTDIR=%buildroot docdir=%_docdir/%name-%version

%__install -m644 -p AUTHORS ACKNOWLEDGEMENTS FAQ.txt NEWS \
	%buildroot%_docdir/%name-%version/

# workaround for trampoline handling problems in old versions of the Openwall
# kernel patch
chstk -e %buildroot%_bindir/%name

# Valgrind shared libraries should not be stripped - see README_PACKAGERS
%set_strip_method executable

# Valgrind low-level routines really need to use %ebx - no chance to make them
# work with -fPIC
%set_verify_elf_method textrel=relaxed

%files
%_bindir/*
%_libdir/%name
%_libdir/pkgconfig/%name.pc
%_docdir/%name-%version
%_mandir/*/*

%files devel
%_includedir/*

%changelog
* Thu May 26 2005 Sergey Vlasov <vsu@altlinux.ru> 2.4.0-alt1
- 2.4.0 release.
- Removed obsolete alt-sigreturn, alt-direct-syscall, alt-pad-check patches.
- Added alt-funobj-suppression patch: allow optional specification of shared
  object name after function name in suppressions (fun:FUNCTION:OBJECT).
- Updated alt-suppressions patch for 2.4.0 and glibc-2.3.5; now using the
  funobj suppression feature for strchr errors in /lib/ld-linux.so.2 (using
  just fun:index hides all errors in strchr/index, using just
  obj:/lib/ld-linux.so.2 hides all errors detected in that object).
- Updated alt-intercept-strmem patch for 2.4.0.
- Added alt-ume-ET_DYN-fixup patch: set load address for ET_DYN executables
  (PIE) at 2/3 of the available address space instead of loading them at
  address 0x00000000.
- Removed AutoProv and __find_requires hacks from spec (no longer required).

* Wed Jun 02 2004 Sergey Vlasov <vsu@altlinux.ru> 2.1.2-alt0.3.20040522
- Fixed fcntl F_GETLK64, F_SETLK64, F_SETLKW64 handling in alt-direct-syscall
  patch.
- Added alt-pad-check patch: exit immediately if as_pad fails instead of
  mysteriously crashing later (can happen if hard address space limits are
  configured).

* Sat May 22 2004 Sergey Vlasov <vsu@altlinux.ru> 2.1.2-alt0.2.20040522
- 20040522 CVS snapshot:
  + teach Massif about the 'nothrow' versions of new and new[]
- Added alt-direct-syscall patch: make libpthread wrappers invoke syscalls
  directly instead of using __libc_* wrappers (which are no longer exported in
  recent glibc versions).

* Wed May 05 2004 Sergey Vlasov <vsu@altlinux.ru> 2.1.2-alt0.1.20040505
- 20040505 CVS snapshot.
- Filter out GLIBC_PRIVATE dependencies.
- Enable executable stack (workaround for GCC trampoline handling bug in the
  Openwall kernel patch).
- Added alt-sigreturn patch: workaround for signal return handling bug in the
  Openwall kernel patch.
- Added alt-suppressions patch: suppress false memcheck error in
  /lib/ld-2.3.3.so (strchr is over-optimized, and the intercept mechanism
  cannot replace it that early).
- Added alt-intercept-strmem patch: use the new intercept mechanism instead of
  symbol override for str*/mem* function replacement (symbol override does not
  work with glibc-2.3.3 because of PLT bypassing, and this leads to lots of
  false errors detected by memcheck).
- Updated BuildRequires.

* Sun Jan 04 2004 Sergey Vlasov <vsu@altlinux.ru> 2.0.0-alt1
- 2.0.0 stable release.
- Updated URL.
- Relaxed TEXTREL check (the low-level code cannot be made PIC).
- Updated BuildRequires.

* Wed Oct 08 2003 Sergey Vlasov <vsu@altlinux.ru> 2.0-alt0.20030725
- 20030725 snapshot.
- Added BuildPreReq: kernel-headers-std.

* Thu May 22 2003 Sergey Vlasov <vsu@altlinux.ru> 1.9.6-alt1
- 1.9.6 release.
- Updated BuildRequires.
- Fixed devel subpackage dependencies.
- Spec file cleanup.

* Thu Nov 21 2002 Sergey Vlasov <vsu@altlinux.ru> 1.0.4-alt1
- 1.0.4 release.
- Do not strip shared libraries.
- Added BuildRequires.

* Mon Jul 29 2002 Alexander Bokovoy <ab@altlinux.ru>
- Initial build.

